@@ -12,7 +12,7 @@ from beziers.path.representations.fontparts import FontParts
 
 __author__ = """Simon Cozens"""
 __email__ = "simon@simon-cozens.org"
-__version__ = "__version__ = '0.6.4'"
+__version__ = "__version__ = '0.7.0'"
 
 
 def categorize_glyph(font, glyphname):
@@ -104,6 +104,7 @@ def get_glyph_metrics(font, glyphname, **kwargs):
             - ``xMax``: maximum X coordinate
             - ``yMin``: minimum Y coordinate
             - ``yMax``: maximum Y coordinate
+            - ``fullwidth``: xMax - xMin
             - ``rise``: difference in Y coordinate between cursive entry and exit
     """
     if glyphtools.glyphs.isglyphs(font):
@@ -149,6 +150,7 @@ def get_glyph_metrics(font, glyphname, **kwargs):
     metrics["rise"] = get_rise(font, glyphname)
     metrics["run"] = get_run(font, glyphname)
     metrics["rsb"] = metrics["width"] - metrics["xMax"]
+    metrics["fullwidth"] = metrics["xMax"] - metrics["xMin"]
     return metrics
 
 
